<div text-align=center>
<img src="/workspaces/Sun-Valley-ttk-theme/nativesunvally cover.png">
<hr>
<h2>Even more windows 11-like! With custom titlebars, Making themed apps is now so easy!</h2>
<h2>Features include:</h2>
<ul>
<li>Native theme support</li>
<li>Titlebar support</li>
<li>And of course, the stunning theme of sv-ttk</li>
</ul>
This is a pull request based off of sv-ttk theme by rdbende
</div>